TextUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getTextHeight(
String text) → int -
getTextWidth(
String text, int charSpacing) → int -
getTextWidthHalo(
String text, {int fontSize = 8}) → int -
Text width on Halo's monospace Dogica font.
fontSizeis the frame.display.set_font size (a multiple of 8; default 8). -
wrapText(
String text, int maxWidth, int charSpacing) → List< String> -
wrapTextHalo(
String text, int maxWidth, {int fontSize = 8}) → List< String> -
Word-wrap
texttomaxWidthpixels using Halo's monospace metrics.
Constants
-
charWidthMapping
→ const Map<
int, int> - haloCharWidth → const int
- Halo: every Dogica glyph advances 8px (at the default 8px font size), and lines advance 10px.
- haloLineHeight → const int